@@ -1,6 +1,7 @@
 import datetime
 import logging
 import time
+from pprint import pprint
 from typing import Any, Dict, List, Optional, Set
 
 from httpcore import NetworkError
@@ -181,6 +182,7 @@ class CheckBoxClient(BaseCheckBoxClient):
         relax: int = DEFAULT_REQUESTS_RELAX,
         timeout: Optional[int] = None,
         storage: Optional[SessionStorage] = None,
+        **payload,
     ):
         storage = storage or self.storage
         self.refresh_info(storage=storage)
@@ -188,7 +190,7 @@ class CheckBoxClient(BaseCheckBoxClient):
             logger.info("Shift is already closed")
             return storage.shift
 
-        shift = self(shifts.CloseShift(), storage=storage)
+        shift = self(shifts.CloseShift(**payload), storage=storage)
         logger.info("Trying to close shift %s", shift["id"])
 
         shift = self._wait_status(
@@ -214,10 +216,13 @@ class CheckBoxClient(BaseCheckBoxClient):
         relax: int = DEFAULT_REQUESTS_RELAX,
         timeout: Optional[int] = None,
         storage: Optional[SessionStorage] = None,
+        wait: bool = True,
         **payload,
     ):
         receipt = self(receipts.CreateReceipt(receipt, **payload), storage=storage)
         logger.info("Trying create receipt %s", receipt["id"])
+        if not wait:
+            return receipt
 
         shift = self._wait_status(
             receipts.GetReceipt(receipt_id=receipt["id"]),
